@@ -17,7 +17,7 @@ class MapFunctions(object):
         self.interp = pol.create_interpolator(interp_method,self.mobj.values,self.mobj.F,self.mobj.M,self.mobj.S)
         self.interp_method = interp_method
         
-    def get_slice(self,central, linear, planar, width, samples, interp_method, log_level=0):
+    def get_slice(self,central, linear, planar, width, samples, interp_method, diff=0, log_level=0):
         # change interpolator if necessary
         if self.interp_method != interp_method:
             self.interp = pol.create_interpolator(interp_method,self.mobj.values,self.mobj.F,self.mobj.M,self.mobj.S)
@@ -37,7 +37,7 @@ class MapFunctions(object):
         xyz_coords = spc.convert_coords(u_coords)
         crs_spc = crs.CrsTransform(dim_order, crs_starts, axis_sampling, map2crs, cell_dims, angles)        
         crs_coords = crs_spc.convert_coords_to_crs(xyz_coords)        
-        vals = self.interp.get_val_slice(crs_coords)
+        vals = self.interp.get_val_slice(crs_coords,diff=diff)
         return vals
         
 
